# Installation

Installing jTWA is simple, however we only tested it on Python 3.12.1.

First, clone the repository using 
```
git clone https://github.com/RehMoritz/jTWA.git
```

Switch into the repository folder..
```
cd jTWA
```
..and create a virtual environment using 
```
python -m venv env
```

Activate the virtual environment with 
```
source env/bin/activate
```

Upgrade pip:
```
pip install --upgrade pip
```

Next, install the dependencies by running 
```
pip install -r requirements.txt
```

In the future we will work towards making jTWA available as a PyPI package.